"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const documenter_ui_section_1 = require("@teambit/documenter.ui.section");
const documenter_theme_theme_compositions_1 = require("@teambit/documenter.theme.theme-compositions");
const documenter_ui_separator_1 = require("@teambit/documenter.ui.separator");
const component_1 = require("@teambit/component");
const workspace_1 = require("@teambit/workspace");
const component_status_resolver_1 = require("./component-status-resolver");
function Overview() {
    return (react_1.default.createElement(documenter_theme_theme_compositions_1.ThemeCompositions, null,
        react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(documenter_ui_section_1.Section, null, "This component wraps the component-status component and component-tooltip so descriptive tooltip is presented when hovering over status icons."),
            react_1.default.createElement(documenter_ui_separator_1.Separator, null))));
}
exports.default = Overview;
Overview.abstract =
    'A UI component that handles the presentation  of the component status and allows to present multiple status options.';
Overview.labels = ['react', 'typescript', 'status', 'tooltip'];
const style = { display: 'flex', justifyContent: 'center', alignContent: 'center' };
Overview.examples = [
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'Modified dependencies',
        description: 'Using the Status Resolver component with modified dependencies',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-1' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: true };
      const isNew = false;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'Modified files',
        description: 'Using the Status Resolver component with modified files',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-2' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: true, hasModifiedDependencies: false };
      const isNew = false;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'New status',
        description: 'Using the Status Resolver component with new status',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-3' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: false };
      const isNew = true;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'Staged status',
        description: 'Using the Status Resolver component with staged status',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-4' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: false };
      const isNew = false;
      const isDeleted = false;
      const isStaged = true;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'New status and issues',
        description: 'Using the Status Resolver component with new status and issues',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-5' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: false };
      const isNew = true;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} issuesCount={1} />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'New staged and issues',
        description: 'Using the Status Resolver component with staged status and issues',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-6' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: false, hasModifiedDependencies: false };
      const isNew = false;
      const isDeleted = false;
      const isStaged = true;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} issuesCount={1} />
        </div>
      );
    }
      `,
    },
    {
        scope: {
            ComponentID: component_1.ComponentID,
            StatusProps: workspace_1.ComponentStatus,
            ComponentStatusResolver: component_status_resolver_1.ComponentStatusResolver,
            style,
        },
        title: 'Modified files and dependencies with issues',
        description: 'Using the Status Resolver component with modified status and issues',
        code: `
    () => {
      // @ts-ignore
      const compId = new ComponentID({ name: 'ui/component-status-resolver-7' }, 'teambit.component');
      const modifyInfo = { hasModifiedFiles: true, hasModifiedDependencies: true };
      const isNew = false;
      const isDeleted = false;
      const isStaged = false;
      const isInWorkspace = false;
      const isInScope = false;
      const nested = false;
      const compStatus = new StatusProps(modifyInfo, isNew, isDeleted, isStaged, isInWorkspace, isInScope, nested);
      return (
        <div style={style}>
          <ComponentStatusResolver id={compId} status={compStatus} issuesCount={1} />
        </div>
      );
    }
      `,
    },
];
//# sourceMappingURL=component-status-resolver.docs.js.map