"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_2 = require("@testing-library/react");
const chai_1 = require("chai");
const component_status_resolver_composition_1 = require("./component-status-resolver.composition");
it('should render a modified status with modified dependencies', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithModifiedDependencies, null));
    const textStatus = getByText(/^D$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltip = getByText(/^Modified dependencies$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltip).to.exist;
});
it('should render a modified status with modified files', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithModifiedFiles, null));
    const textStatus = getByText(/^M$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltip = getByText(/^Modified files$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltip).to.exist;
});
it('should render a new status with new component', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithNewStatus, null));
    const textStatus = getByText(/^N$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltip = getByText(/^New component$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltip).to.exist;
});
it('should render a staged status with staged component', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithStagedStatus, null));
    const textStatus = getByText(/^S$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltip = getByText(/^Staged component$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltip).to.exist;
});
it('should render a new status with issue', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithNewStatusAndIssue, null));
    const textStatus = getByText(/^N$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltip = getByText(/^New component$/);
    const textTooltipIssue = getByText(/^1 issue found$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltip).to.exist;
    (0, chai_1.expect)(textTooltipIssue).to.exist;
});
it('should render a staged status with issue', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithStagedStatusAndIssue, null));
    const textStatus = getByText(/^S$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltip = getByText(/^Staged component$/);
    const textTooltipIssue = getByText(/^1 issue found$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltip).to.exist;
    (0, chai_1.expect)(textTooltipIssue).to.exist;
});
it('should render a modified dependencies and files status with issue', () => {
    const { getByText } = (0, react_2.render)(react_1.default.createElement(component_status_resolver_composition_1.ComponentStatusResolverWithModifiedStatusAndIssue, null));
    const textStatus = getByText(/^M$/);
    textStatus.parentElement && react_2.fireEvent.mouseEnter(textStatus.parentElement);
    const textTooltipIssue = getByText(/^1 issue found$/);
    const textModifiedDependencies = getByText(/^Modified dependencies$/);
    const textModifiedFiles = getByText(/^Modified files$/);
    (0, chai_1.expect)(textStatus).to.exist;
    (0, chai_1.expect)(textTooltipIssue).to.exist;
    (0, chai_1.expect)(textModifiedDependencies).to.exist;
    (0, chai_1.expect)(textModifiedFiles).to.exist;
});
//# sourceMappingURL=component-status-resolver.spec.js.map